# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deutschland',
 'deutschland.pegel_online',
 'deutschland.pegel_online.api',
 'deutschland.pegel_online.apis',
 'deutschland.pegel_online.model',
 'deutschland.pegel_online.models']

package_data = \
{'': ['*']}

install_requires = \
['python-dateutil', 'urllib3>=1.25.3']

setup_kwargs = {
    'name': 'de-pegel-online',
    'version': '0.1.0',
    'description': 'Wasserstraßen- und Schifffahrtsverwaltung: Pegel-Online API',
    'long_description': '# pegel-online\nAPI für das bundesweite Messstellennetz der Wasserstraßen- und Schifffahrtsverwaltung des Bundes.\n\nDie API stellt drei verschiedene Ressourcen zur Verfügung: __Station__, __Measurement__, __Water__.\n### Authentifizierung / Autorisierung / API Limitierung\nEs ist keine Authentifizierung oder Autorisierung notwendig. Aktuell besteht keine API Limitierung.\n### Allgemeine Query-Parameter\nZusätzlich zu den angegebenen Parametern sind ebenfalls allgemeine Parameter für alle Schnittstellen verfügbar ([Dokumentation](https://www.pegelonline.wsv.de/webservice/dokuRestapi;jsessionid=A294589CCEF6630142D2589F49BFA2EC#urlParameter)).\n- `charset`: Gibt die Kodierung der Response an. Standard ist hier _UTF-8_. Möglich ist z.B. auch _ISO-8859-1_.\n- `prettyprint`: Kann die zur besseren Lesbarkeit standardmäßig aktivierte Teilung der Response in mehreren Zeilen deaktivieren: _prettyprint=false_. Diese Einstellung wird für den produktiven Einsatz empfohlen.\n- `limit/offset`: Einschränkung der Anzahl der Ergebnisse. Hiermit kann \'Pagination\' realisiert werden. `limit` gibt dabei die Anzahl der zurückgegebenen Elemente an. `offset` ermöglicht einen Offset vom Startwert. Beispiel: _limit=10&offset=20_ bedeutet, dass 10 Elemente beginnend mit dem 21. Element zurückgegeben werden. \n\nThis Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:\n\n- API version: 1.0.0\n- Package version: 0.1.0\n- Build package: org.openapitools.codegen.languages.PythonClientCodegen\n\n## Requirements.\n\nPython >= 3.6\n\n## Installation & Usage\n### pip install\n\n```sh\npip install deutschland[pegel_online]\n```\n\n### poetry install\n\n```sh\npoetry add deutschland -E pegel_online\n```\n\n### Setuptools\n\nInstall via [Setuptools](http://pypi.python.org/pypi/setuptools).\n\n```sh\npython setup.py install --user\n```\n(or `sudo python setup.py install` to install the package for all users)\n\n## Usage\n\nImport the package:\n```python\nfrom deutschland import pegel_online\n```\n\n## Getting Started\n\nPlease follow the [installation procedure](#installation--usage) and then run the following:\n\n```python\n\nimport time\nfrom deutschland import pegel_online\nfrom pprint import pprint\nfrom deutschland.pegel_online.api import measurement_api\nfrom deutschland.pegel_online.model.measurement_result import MeasurementResult\n# Defining the host is optional and defaults to https://www.pegelonline.wsv.de/webservices/rest-api/v2\n# See configuration.py for a list of all supported configuration parameters.\nconfiguration = pegel_online.Configuration(\n    host = "https://www.pegelonline.wsv.de/webservices/rest-api/v2"\n)\n\n\n\n# Enter a context with an instance of the API client\nwith pegel_online.ApiClient(configuration) as api_client:\n    # Create an instance of the API class\n    api_instance = measurement_api.MeasurementApi(api_client)\n    station = "593647aa-9fea-43ec-a7d6-6476a76ae868" # str | UUID / Name / Pegelnummer der Station.\ntimeseries = "" # str | timeseries shortname\nstart = "2022-02-06T09:00:00+01:00" # str | Zeitpunkt codiert im [ISO_8601](https://de.wikipedia.org/wiki/ISO_8601) Format. Angabe eines Datums oder einer Period (_P_, z.B. \\"P8D\\" für die Messwerte der letzten 8 Tage) sind möglich. (optional)\nend = "" # str | Endzeitpunkt codiert im [ISO_8601](https://de.wikipedia.org/wiki/ISO_8601) Format. Kann auch leer gelassen werden, dann wird automatisch der aktuelle Zeitstempel verwendet. (optional)\n\n    try:\n        # Zugriff auf die Ressource Measurement\n        api_response = api_instance.stations_station_timeseries_measurements_json_get(station, timeseries, start=start, end=end)\n        pprint(api_response)\n    except pegel_online.ApiException as e:\n        print("Exception when calling MeasurementApi->stations_station_timeseries_measurements_json_get: %s\\n" % e)\n```\n\n## Documentation for API Endpoints\n\nAll URIs are relative to *https://www.pegelonline.wsv.de/webservices/rest-api/v2*\n\nClass | Method | HTTP request | Description\n------------ | ------------- | ------------- | -------------\n*MeasurementApi* | [**stations_station_timeseries_measurements_json_get**](docs/MeasurementApi.md#stations_station_timeseries_measurements_json_get) | **GET** /stations/{station}/{timeseries}/measurements.json | Zugriff auf die Ressource Measurement\n*MeasurementApi* | [**stations_station_timeseries_measurements_png_get**](docs/MeasurementApi.md#stations_station_timeseries_measurements_png_get) | **GET** /stations/{station}/{timeseries}/measurements.png | Zugriff auf die Ressource Measurement - Rückgabe als Diagramm (PNG)\n*StationApi* | [**stations_json_get**](docs/StationApi.md#stations_json_get) | **GET** /stations.json | Übersicht über alle Stationen (Pegel)\n*StationApi* | [**stations_station_json_get**](docs/StationApi.md#stations_station_json_get) | **GET** /stations/{station}.json | Zugriff auf eine bestimmte Station (Pegel)\n*WaterApi* | [**stations_station_timeseries_json_get**](docs/WaterApi.md#stations_station_timeseries_json_get) | **GET** /stations/{station}/{timeseries}.json | Zugriff auf CurrentMeasurment\n*WaterApi* | [**waters_json_get**](docs/WaterApi.md#waters_json_get) | **GET** /waters.json | Zugriff auf die Ressource Water\n\n\n## Documentation For Models\n\n - [Comment](docs/Comment.md)\n - [CurrentMeasurement](docs/CurrentMeasurement.md)\n - [MeasurementResult](docs/MeasurementResult.md)\n - [StationOverviewResult](docs/StationOverviewResult.md)\n - [Timeseries](docs/Timeseries.md)\n - [TimeseriesGaugeZero](docs/TimeseriesGaugeZero.md)\n - [WaterResult](docs/WaterResult.md)\n\n\n## Documentation For Authorization\n\n All endpoints do not require authorization.\n\n## Author\n\nkontakt@bund.dev\n\n\n## Notes for Large OpenAPI documents\nIf the OpenAPI document is large, imports in pegel_online.apis and pegel_online.models may fail with a\nRecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:\n\nSolution 1:\nUse specific imports for apis and models like:\n- `from deutschland.pegel_online.api.default_api import DefaultApi`\n- `from deutschland.pegel_online.model.pet import Pet`\n\nSolution 2:\nBefore importing the package, adjust the maximum recursion limit as shown below:\n```\nimport sys\nsys.setrecursionlimit(1500)\nfrom deutschland import pegel_online\nfrom deutschland.pegel_online.apis import *\nfrom deutschland.pegel_online.models import *\n```\n\n',
    'author': 'BundesAPI',
    'author_email': 'kontakt@bund.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bundesAPI/pegel-online-api',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6',
}


setup(**setup_kwargs)
